summaryrefslogtreecommitdiffstats
path: root/chrome/browser/gtk/browser_window_gtk.h
diff options
context:
space:
mode:
authorestade@chromium.org <estade@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-11-06 21:09:57 +0000
committerestade@chromium.org <estade@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-11-06 21:09:57 +0000
commit58e23f78f5b1666cda9a0ab43ae6314026a88787 (patch)
tree219c2f3e69f017c4c0fa14dc307d9f98b8da3808 /chrome/browser/gtk/browser_window_gtk.h
parent97a1d694d347ce8b84fca7ed1e17782726138f54 (diff)
downloadchromium_src-58e23f78f5b1666cda9a0ab43ae6314026a88787.zip
chromium_src-58e23f78f5b1666cda9a0ab43ae6314026a88787.tar.gz
chromium_src-58e23f78f5b1666cda9a0ab43ae6314026a88787.tar.bz2
GTK: Change find bar to use a floating container rather than some hacked up gtkfixed business.
The straw that broke this camel's back was when I realized that showing the findbar in fullscreen mode would inescapably mean an extra 1 pixel border at the top. Also fix z-ordering problems for findbar that have been around since I introduced the floating bookmark bar (the fact that no one filed a bug on this suggests that it's not that noticeable). BUG=none TEST=find bar still works. find bar works in fullscreen. the toolbar bottom border still exists at all times. there are no z-ordering problems. the find bar still gets out of way of find results. Review URL: http://codereview.chromium.org/373007 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@31296 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/gtk/browser_window_gtk.h')
-rw-r--r--chrome/browser/gtk/browser_window_gtk.h5
1 files changed, 4 insertions, 1 deletions
diff --git a/chrome/browser/gtk/browser_window_gtk.h b/chrome/browser/gtk/browser_window_gtk.h
index 65c18b0..cb272ad 100644
--- a/chrome/browser/gtk/browser_window_gtk.h
+++ b/chrome/browser/gtk/browser_window_gtk.h
@@ -213,7 +213,10 @@ class BrowserWindowGtk : public BrowserWindow,
GtkWidget* window_vbox_;
// VBox that holds everything below the toolbar.
GtkWidget* render_area_vbox_;
- // EventBox that holds render_area_vbox_.
+ // Floating container that holds the render area. It is needed to position
+ // the findbar.
+ GtkWidget* render_area_floating_container_;
+ // EventBox that holds render_area_floating_container_.
GtkWidget* render_area_event_box_;
// Border between toolbar and render area. This is hidden when the find bar
// is added because thereafter the findbar will draw the border for us.